@@ -23,8 +23,9 @@ use {
     solana_poh::poh_recorder::WorkingBankEntry,
     solana_runtime::{bank::Bank, bank_forks::BankForks},
     solana_sdk::{
+        clock::Slot,
+        pubkey::Pubkey,
         timing::{timestamp, AtomicInterval},
-        {clock::Slot, pubkey::Pubkey},
     },
     solana_streamer::{
         sendmmsg::{batch_send, SendPktsError},
@@ -449,24 +450,28 @@ pub fn broadcast_shreds(
 
 #[cfg(test)]
 pub mod test {
-    use super::*;
-    use crossbeam_channel::unbounded;
-    use solana_gossip::cluster_info::{ClusterInfo, Node};
-    use solana_ledger::{
-        blockstore::{make_slot_entries, Blockstore},
-        entry::create_ticks,
-        genesis_utils::{create_genesis_config, GenesisConfigInfo},
-        get_tmp_ledger_path,
-        shred::{max_ticks_per_n_shreds, ProcessShredsStats, Shredder},
-    };
-    use solana_runtime::bank::Bank;
-    use solana_sdk::{
-        hash::Hash,
-        pubkey::Pubkey,
-        signature::{Keypair, Signer},
-    };
-    use std::{
-        path::Path, sync::atomic::AtomicBool, sync::mpsc::channel, sync::Arc, thread::sleep,
+    use {
+        super::*,
+        crossbeam_channel::unbounded,
+        solana_gossip::cluster_info::{ClusterInfo, Node},
+        solana_ledger::{
+            blockstore::{make_slot_entries, Blockstore},
+            entry::create_ticks,
+            genesis_utils::{create_genesis_config, GenesisConfigInfo},
+            get_tmp_ledger_path,
+            shred::{max_ticks_per_n_shreds, ProcessShredsStats, Shredder},
+        },
+        solana_runtime::bank::Bank,
+        solana_sdk::{
+            hash::Hash,
+            pubkey::Pubkey,
+            signature::{Keypair, Signer},
+        },
+        std::{
+            path::Path,
+            sync::{atomic::AtomicBool, mpsc::channel, Arc},
+            thread::sleep,
+        },
     };
 
     #[allow(clippy::implicit_hasher)]
