@@ -1,6 +1,8 @@
-use crate::heaviest_subtree_fork_choice::SlotHashKey;
-use solana_sdk::{clock::Slot, hash::Hash, pubkey::Pubkey};
-use std::collections::{hash_map::Entry, HashMap};
+use {
+    crate::heaviest_subtree_fork_choice::SlotHashKey,
+    solana_sdk::{clock::Slot, hash::Hash, pubkey::Pubkey},
+    std::collections::{hash_map::Entry, HashMap},
+};
 
 #[derive(Default)]
 pub(crate) struct LatestValidatorVotesForFrozenBanks {
