@@ -13,7 +13,7 @@ use {
     solana_sdk::timing,
     solana_streamer::streamer::{self, PacketBatchReceiver, StreamerError},
     std::{
-        collections::HashMap,
+        collections::{HashMap, VecDeque},
         sync::mpsc::{Receiver, RecvTimeoutError},
         thread::{self, Builder, JoinHandle},
         time::Instant,
@@ -49,6 +49,7 @@ pub struct DisabledSigVerifier {}
 struct SigVerifierStats {
     recv_batches_us_hist: histogram::Histogram, // time to call recv_batch
     verify_batches_pp_us_hist: histogram::Histogram, // per-packet time to call verify_batch
+    discard_packets_pp_us_hist: histogram::Histogram, // per-packet time to call verify_batch
     batches_hist: histogram::Histogram,         // number of packet batches per verify call
     packets_hist: histogram::Histogram,         // number of packets per verify call
     total_batches: usize,
@@ -99,6 +100,28 @@ impl SigVerifierStats {
                 self.verify_batches_pp_us_hist.mean().unwrap_or(0),
                 i64
             ),
+            (
+                "discard_packets_pp_us_90pct",
+                self.discard_packets_pp_us_hist
+                    .percentile(90.0)
+                    .unwrap_or(0),
+                i64
+            ),
+            (
+                "discard_packets_pp_us_min",
+                self.discard_packets_pp_us_hist.minimum().unwrap_or(0),
+                i64
+            ),
+            (
+                "discard_packets_pp_us_max",
+                self.discard_packets_pp_us_hist.maximum().unwrap_or(0),
+                i64
+            ),
+            (
+                "discard_packets_pp_us_mean",
+                self.discard_packets_pp_us_hist.mean().unwrap_or(0),
+                i64
+            ),
             (
                 "batches_90pct",
                 self.batches_hist.percentile(90.0).unwrap_or(0),
@@ -145,17 +168,17 @@ impl SigVerifyStage {
             for (packet_index, packets) in batch.packets.iter().enumerate() {
                 let e = received_ips
                     .entry(packets.meta.addr().ip())
-                    .or_insert_with(Vec::new);
-                e.push((batch_index, packet_index));
+                    .or_insert_with(VecDeque::new);
+                e.push_back((batch_index, packet_index));
             }
         }
         let mut batch_len = 0;
         while batch_len < max_packets {
             for (_ip, indexes) in received_ips.iter_mut() {
                 if !indexes.is_empty() {
-                    indexes.remove(0);
+                    indexes.pop_front();
                     batch_len += 1;
-                    if batch_len >= MAX_SIGVERIFY_BATCH {
+                    if batch_len >= max_packets {
                         break;
                     }
                 }
@@ -179,9 +202,11 @@ impl SigVerifyStage {
         let mut verify_batch_time = Measure::start("sigverify_batch_time");
         let batches_len = batches.len();
         debug!("@{:?} verifier: verifying: {}", timing::timestamp(), len,);
+        let mut discard_time = Measure::start("sigverify_discard_time");
         if len > MAX_SIGVERIFY_BATCH {
             Self::discard_excess_packets(&mut batches, MAX_SIGVERIFY_BATCH);
         }
+        discard_time.stop();
         sendr.send(verifier.verify_batches(batches))?;
         verify_batch_time.stop();
 
@@ -210,6 +235,10 @@ impl SigVerifyStage {
             .verify_batches_pp_us_hist
             .increment(verify_batch_time.as_us() / (len as u64))
             .unwrap();
+        stats
+            .discard_packets_pp_us_hist
+            .increment(discard_time.as_us() / (len as u64))
+            .unwrap();
         stats.batches_hist.increment(batches_len as u64).unwrap();
         stats.packets_hist.increment(len as u64).unwrap();
         stats.total_batches += batches_len;
